@@ -1,7 +1,6 @@
 # -*- encoding=utf-8 -*-
 import sys
 import ruamel.yaml
-from termcolor import colored
 
 
 def read_yaml_file():
@@ -10,7 +9,7 @@ def read_yaml_file():
         with open('article_rules.yaml', 'r', encoding='utf-8') as fr:
             return ruamel.yaml.load(fr.read(), Loader=ruamel.yaml.Loader)
     except:
-        print(colored('error: ', 'red'), '读取rules文件失败.')
+        print('读取rules文件失败.')
         sys.exit()
 
 
